def thetadic05() -> None: ...
def f05(t, y, phi, phit, theta, te) -> None: ...
def thetadic06() -> None: ...
def f06(t, y, phi, phit, theta, te) -> None: ...
def thetadic07() -> None: ...
def f07(t, y, phi, phit, theta, te) -> None: ...
def thetadic11() -> None: ...
def f11(t, y, phi, phit, theta, te) -> None: ...
def thetadic08() -> None: ...
def f08(t, y, phi, phit, theta, te) -> None: ...
def thetadic09() -> None: ...
def f09(t, y, phi, phit, theta, te) -> None: ...
def thetadic12() -> None: ...
def f12(t, y, phi, phit, theta, te) -> None: ...
def thetadic13() -> None: ...
def f13(t, y, phi, phit, theta, te) -> None: ...
def thetadic14() -> None: ...
def f14(t, y, phi, phit, theta, te) -> None: ...
def thetadic14p() -> None: ...
def f14p(t, y, phi, phit, theta, te) -> None: ...
def thetadic14s() -> None: ...
def f14s(t, y, phi, phit, theta, te) -> None: ...
def thetadic15() -> None: ...
def f15(t, y, phi, phit, theta, te) -> None: ...
def thetadic16() -> None: ...
def f16(t, y, phi, phit, theta, te) -> None: ...
def thetadic17() -> None: ...
def f17(t, y, phi, phit, theta, te) -> None: ...
def thetadic22() -> None: ...
def f22(t, y, phi, phit, theta, te) -> None: ...
