def validation(data_storage, model_structure, modelling_settings, estimation_settings, Simula, round_data, framework_settings) -> None: ...
def compute_validation_error(resultun_pred, resultun_val, scaled_params, round_data) -> None: ...
